using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.OpenApi.Models;
using Robware.Mailboxes;
using Robware.Mailboxes.Data;
using Robware.Lib.Auth.ApiKey;

namespace Robware.Api.Mailboxes {
	public class Startup {
		public Startup(IConfiguration configuration) {
			Configuration = configuration;
		}

		public IConfiguration Configuration { get; }	

		public void ConfigureServices(IServiceCollection services) {
			services.AddSingleton<IDatabaseProvider>(new MySQLDatabaseProvider(Configuration.GetConnectionString("database")));
			services.AddSingleton<IAliases, AliasRepository>();
			services.AddControllers();
			services.AddSwaggerGen(c => {
				c.SwaggerDoc("v1", new OpenApiInfo {Title = "Robware.Api.Mailboxes", Version = "v1"});
			});
			services.AddApiKeyAuthentication(Configuration["authEndpoint"], Configuration["authApiKey"]);
		}

		public void Configure(IApplicationBuilder app, IWebHostEnvironment env) {
			if (env.IsDevelopment()) {
				app.UseDeveloperExceptionPage();
				app.UseSwagger();
				app.UseSwaggerUI(c => c.SwaggerEndpoint("/swagger/v1/swagger.json", "Robware.Api.Mailboxes v1"));
			}

			app.UseHttpsRedirection();

			app.UseRouting();
			app.UseAuthentication();
			app.UseAuthorization();

			app.UseEndpoints(endpoints => {
				endpoints.MapControllers().RequireAuthorization();
			});
		}
	}
}